@@ -1,6 +1,6 @@
 from .constants import *
 from .frame import Frame, ColumnInfo
 from .encoder import encode_odb
-from .reader import Reader, read_odb, read_odb_oneshot
+from .reader import Reader, read_odb
 
-__version__ = "1.0.1"
+__version__ = "1.0.3"
