@@ -1,6 +1,6 @@
 from .frame import Frame, MismatchedFramesError
 
-from functools import reduce
+import pandas
 import io
 
 
@@ -40,11 +40,24 @@ class Reader:
         return self._frames
 
 
-def read_odb(source, columns=None, aggregated=True):
+def _read_odb_generator(source, columns=None, aggregated=True):
     r = Reader(source, aggregated=aggregated)
     for f in r.frames:
         yield f.dataframe(columns)
 
 
-def read_odb_oneshot(source, columns=None):
-    return reduce(lambda df1, df2: df1.append(df2, sort=False), read_odb(source, columns))
+def _read_odb_oneshot(source, columns=None):
+    reduced = pandas.concat(_read_odb_generator(source, columns), sort=False, ignore_index=True)
+    for name, data in reduced.iteritems():
+        if data.dtype == 'object':
+            data.where(pandas.notnull(data), None, inplace=True)
+    return reduced
+
+
+def read_odb(source, columns=None, aggregated=True, single=False):
+    if single:
+        assert aggregated
+        return _read_odb_oneshot(source, columns)
+    else:
+        return _read_odb_generator(source, columns, aggregated)
+
